==> arrow-docs-0.8.1-sources.jar: com/example/domain/Street$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Street`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Street`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Iso(
  get = { street: `com`.`example`.`domain`.`Street` -> arrow.core.Tuple2(street.`number`, street.`name`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`> -> `com`.`example`.`domain`.`Street`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Street`.Companion.number: arrow.optics.Lens<`com`.`example`.`domain`.`Street`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { street: `com`.`example`.`domain`.`Street` -> street.`number` },
  set = { value: `kotlin`.`Int` ->
    { street: `com`.`example`.`domain`.`Street` ->
      street.copy(`number` = value)
    }
  }
)

inline val `com`.`example`.`domain`.`Street`.Companion.name: arrow.optics.Lens<`com`.`example`.`domain`.`Street`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { street: `com`.`example`.`domain`.`Street` -> street.`name` },
  set = { value: `kotlin`.`String` ->
    { street: `com`.`example`.`domain`.`Street` ->
      street.copy(`name` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name

==> arrow-docs-0.9.0-sources.jar: com/example/domain/Street$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Street`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Street`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`>> inline get()= arrow.optics.Iso(
  get = { street: `com`.`example`.`domain`.`Street` -> arrow.core.Tuple2(street.`number`, street.`name`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`String`> -> `com`.`example`.`domain`.`Street`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Street`.Companion.number: arrow.optics.Lens<`com`.`example`.`domain`.`Street`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { street: `com`.`example`.`domain`.`Street` -> street.`number` },
  set = { street: `com`.`example`.`domain`.`Street`, value: `kotlin`.`Int` -> street.copy(`number` = value) }
)

inline val `com`.`example`.`domain`.`Street`.Companion.name: arrow.optics.Lens<`com`.`example`.`domain`.`Street`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { street: `com`.`example`.`domain`.`Street` -> street.`name` },
  set = { street: `com`.`example`.`domain`.`Street`, value: `kotlin`.`String` -> street.copy(`name` = value) }
)




inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Street`>.number: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `com`.`example`.`domain`.`Street`.number

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Street`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Street`.name
